@@ -13,7 +13,7 @@ input_sample = samples[0]
 output_sample = samples[1]
 nnet_sample = neuralNetwork(input_sample)
 diff_sample = nnet_sample - output_sample
-result_sample = ot.NumericalSample(input_sample)
+result_sample = ot.Sample(input_sample)
 result_sample.stack(output_sample)
 result_sample.stack(nnet_sample)
 result_sample.stack(diff_sample)
@@ -21,7 +21,7 @@ result_sample.setDescription(ot.Description(["E", "F", "L", "I", "expected", "nn
 print(result_sample)
 
 # Comparison of neuralNetwork with the original function
-poutre = ot.NumericalMathFunction(["E", "F", "L", "I"],["F*L^3/(3*E*I)"])
+poutre = ot.Function(["E", "F", "L", "I"],["F*L^3/(3*E*I)"])
 print("poutre=" , repr(poutre))
 
 # Compare gradient & hessian
